# Changelog

## 0.1.0-alpha.3 (2024-12-03)

Full Changelog: [v0.1.0-alpha.2...v0.1.0-alpha.3](https://github.com/phoebe-bird/phoebe-python/compare/v0.1.0-alpha.2...v0.1.0-alpha.3)

### Bug Fixes

* **api:** get repo clean ([#14](https://github.com/phoebe-bird/phoebe-python/issues/14)) ([28470b8](https://github.com/phoebe-bird/phoebe-python/commit/28470b8579956fe39e92b6aa55a89d34fffd5ff4))
* **client:** compat with new httpx 0.28.0 release ([#25](https://github.com/phoebe-bird/phoebe-python/issues/25)) ([10748d0](https://github.com/phoebe-bird/phoebe-python/commit/10748d06f5154bfc9fd7bffb9a035aff449189b5))


### Chores

* **internal:** bump pyright ([#26](https://github.com/phoebe-bird/phoebe-python/issues/26)) ([b6362e9](https://github.com/phoebe-bird/phoebe-python/commit/b6362e9376aa5ceb958970682459e906727a4a45))
* **internal:** exclude mypy from running on tests ([#24](https://github.com/phoebe-bird/phoebe-python/issues/24)) ([2ab77ee](https://github.com/phoebe-bird/phoebe-python/commit/2ab77ee42f02eba645742b4eacab7b10581ead61))
* **internal:** fix compat model_dump method when warnings are passed ([#21](https://github.com/phoebe-bird/phoebe-python/issues/21)) ([7897301](https://github.com/phoebe-bird/phoebe-python/commit/7897301d160007df9e843c97f60481536bd07293))
* rebuild project due to codegen change ([#16](https://github.com/phoebe-bird/phoebe-python/issues/16)) ([19478a7](https://github.com/phoebe-bird/phoebe-python/commit/19478a7560434c8c2a1fa0b1680a6bbdd8307552))
* rebuild project due to codegen change ([#17](https://github.com/phoebe-bird/phoebe-python/issues/17)) ([698aecb](https://github.com/phoebe-bird/phoebe-python/commit/698aecbd81367cbfd331f0c78bbfc85f3cfcc012))
* rebuild project due to codegen change ([#18](https://github.com/phoebe-bird/phoebe-python/issues/18)) ([766d1a8](https://github.com/phoebe-bird/phoebe-python/commit/766d1a82564c074073e51bae85da72a069ede68f))
* rebuild project due to codegen change ([#19](https://github.com/phoebe-bird/phoebe-python/issues/19)) ([59ef073](https://github.com/phoebe-bird/phoebe-python/commit/59ef073731a6377866f9c6bc00e2fe53f4ce150e))
* rebuild project due to codegen change ([#20](https://github.com/phoebe-bird/phoebe-python/issues/20)) ([26413bd](https://github.com/phoebe-bird/phoebe-python/commit/26413bdf5fb60322d22a22cac4f0ac01d6029a0a))
* remove now unused `cached-property` dep ([#23](https://github.com/phoebe-bird/phoebe-python/issues/23)) ([5eba39b](https://github.com/phoebe-bird/phoebe-python/commit/5eba39bc3dab9ad10e8b82ed8c5cc875b688df42))


### Documentation

* add info log level to readme ([#22](https://github.com/phoebe-bird/phoebe-python/issues/22)) ([e37a2fc](https://github.com/phoebe-bird/phoebe-python/commit/e37a2fc11b65f4e975262a766f2d6d08545e14b5))

## 0.1.0-alpha.2 (2024-07-07)

Full Changelog: [v0.1.0-alpha.1...v0.1.0-alpha.2](https://github.com/phoebe-bird/phoebe-python/compare/v0.1.0-alpha.1...v0.1.0-alpha.2)

### Features

* **docs:** update contact email ([#12](https://github.com/phoebe-bird/phoebe-python/issues/12)) ([1cadb56](https://github.com/phoebe-bird/phoebe-python/commit/1cadb564708531b50fc1d49a683b044e94708ab4))

## 0.1.0-alpha.1 (2024-07-07)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/phoebe-bird/phoebe-python/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** add docs to openapi spec ([#6](https://github.com/phoebe-bird/phoebe-python/issues/6)) ([48a914e](https://github.com/phoebe-bird/phoebe-python/commit/48a914ed6c19b308129b6ddb87b47600772b12f7))
* **api:** add python ([#1](https://github.com/phoebe-bird/phoebe-python/issues/1)) ([32d688d](https://github.com/phoebe-bird/phoebe-python/commit/32d688d87fe45ec05fe15306d48632eb246eaacf))
* **api:** fix adjacent region ([#5](https://github.com/phoebe-bird/phoebe-python/issues/5)) ([2eb594d](https://github.com/phoebe-bird/phoebe-python/commit/2eb594db27e90b97532c0fb52ebf12b93cf3e297))
* **api:** manual updates ([#3](https://github.com/phoebe-bird/phoebe-python/issues/3)) ([13a0146](https://github.com/phoebe-bird/phoebe-python/commit/13a0146de8696542ad5631252ff10851f85b06ba))


### Chores

* configure new SDK language ([0c39913](https://github.com/phoebe-bird/phoebe-python/commit/0c39913d143536aa1d7e096e79a74ad2ab8d973e))
* update SDK settings ([4174038](https://github.com/phoebe-bird/phoebe-python/commit/4174038355ba0b0c5ef9777709a00c5478925eaf))
* update SDK settings ([#4](https://github.com/phoebe-bird/phoebe-python/issues/4)) ([738803c](https://github.com/phoebe-bird/phoebe-python/commit/738803cff82bd54b44b8746f4b0fd5162c27ec1b))
* update SDK settings ([#7](https://github.com/phoebe-bird/phoebe-python/issues/7)) ([ee04119](https://github.com/phoebe-bird/phoebe-python/commit/ee041194307a44b0e723e7441a1e778e34495e5e))
